#!/usr/bin/env python
"""
This class generate the full information showed in the history page of T0Mon

The alghoritm try to cover a graph where Vertex= Tables and Edges = SQL queries.
The input is the (unique) Id of a vertex, then from that I try to derive the id values for the connected vertex [executing the correspondending edge-sql]
   
The final output is another scan of the vertex executing the print* sql queries.
Such queries collects the information to be showed in the output tables   

"""
from WMCore.Database.DBFormatter import DBFormatter
from math import ceil

class AllHistory(DBFormatter):
    """  
    _This class collect information from different tables in order to have a complete view of the data connected to a single
   (Streamer | (Express | Reco | Repack | AlcaSkim) +[Merge] + (file | job)). These are also all the possible input values_
    """
    #Ids= save the Ids for the * files tables. This values are used to connect the different sets of tables
    Ids ={'strm': [],'exprF': [], 'exprJ':[],'exprMJ': [], 'exprMF':[],'DQMJ':[],'repkJ':[],'repkF':[],'repkMJ':[],'repkMF':[], 'recoJ':[],'recoF':[],'recoMJ':[],'recoMF':[],'alcaJ':[],'alcaF':[],'alcaMJ':[],'alcaMF':[],'StraightToMerge':[]}
    tableNames={'strm':"StreamerFiles",'exprF':"ExpressFiles",'exprJ':"ExpressJobs",'exprMJ':"ExpressMergeJobs",'exprMF':"ExpressMergeFiles",'repkF':"RepackFiles",'repkJ':"RepackJobs",'repkMJ':"RepackMergeJobs",'repkMF':"RepackMergeFiles",'recoF':"RecoFiles",'recoJ':"RecoJobs",'recoMJ':"RecoMergeJobs",'recoMF':"RecoMergeFiles",'alcaF':"AlcaFiles",'alcaJ':"AlcaJobs",'alcaMJ':"AlcaMergeJobs",'alcaMF':"AlcaMergeFiles",'DQMJ':"DQMJobs"}
  #
    orderExpr={'strm': ['exprJ','exprF'],'exprJ':['strm'],'exprF':['exprMF','exprMJ','strm','DQMJ'],'exprMF':['exprMJ','DQMJ'],'exprMJ':['exprF'],'DQMJ':['exprMF','exprF']} 
    
    orderRepk={'strm': ['repkJ','repkF'],'repkJ':['strm'],'repkF':['repkJ','repkMF','repkMJ'],'repkMF':['repkMJ','recoJ','recoF','repkJ'],'repkMJ':['repkF'], 'recoF':['recoMF','recoMJ','recoJ','alcaF','alcaJ'],'recoJ':['recoF','repkMF'],'recoMJ':['recoF'],'recoMF':['recoF'],'alcaF':['alcaMF','alcaMJ','alcaJ'],'alcaJ':['recoF'], 'alcaMF':['alcaF','alcaMJ'], 'alcaMJ':['alcaF']}
    MAXDIM=200
    checkedStraightToMerge=False
    # Output table names
    
  
    
    def execute(self,vtype,value, conn = None, transaction = False):
        """
        analysis of the parameters and running: generateAllIds() and then buildTables()
        """
        vtype=vtype.lower()
        self.conn = conn
        self.transaction = transaction
        self.vtype=vtype
        self.value=value
        
        self.order=self.orderRepk
        if self.vtype[0:4]=="expr" or self.vtype[0:3]=="dqm" or self.strmExprGreaterThenBulks() :
            self.order=self.orderExpr
	
        current=None
        for key in self.Ids:
          self.Ids[key]=[]
       
        try: 
          if len(vtype)>4:
           current = vtype[0:4]+vtype[4:].upper()
	  elif vtype[0:3]=="dqm":
            current = vtype.upper()
          else: current = vtype
          self.Ids[current]=[value,] 
          
        except Exception, e:
           print e
           current=None
        #print "IDs="+str(self.Ids)
	#print "current="+str(current)
        if current not in self.Ids.keys():
          return {"Error" : "wrong input type",'current': vtype,'allowed vtype values: ': "strm|(repk|reco|alca|expr)+[M]+(j|f)"} 
        self.generateAllIds(current)
        #for i in self.Ids:
            #print "Ids[%s]=%s"%(i,self.Ids[i])
        return self.buildTables()
          
        
    def generateAllIds(self,current):
        """
        This method scan the graph from the starting point (current) recursively and fill the Ids dictionary with all the different table ids.
        """
        if len(self.Ids[current])>0:
          if (current in self.order):
           for target in self.order[current]:
            if self.Ids[target]==[]:
             #print " recursion on "+ str(target) + " from "+str(current)+"  "+str(self.Ids[current])+"  "+""   ############## useful debug print
             self.Ids[target]= self.getIdsQuery(current,target)
             ##########################special case: StraightToMerge use case
             if self.Ids['repkF']!=[] and not self.checkedStraightToMerge:
                 self.Ids['StraightToMerge']=self.getIdsQuery('repkF','repkMF',option="StraightToMerge")
                 self.checkedStraightToMerge=True
                 if self.Ids['repkMF']!=[]:  self.Ids[target]+=self.Ids['StraightToMerge']
                 self.deleteIds('repkF',self.Ids['StraightToMerge'])
             if target=='repkMF' and self.checkedStraightToMerge:
                 self.Ids[target]+=self.Ids['StraightToMerge']
             # drop repkJ/repkMJ if looking for only  StraightToMerge files
             if self.Ids['StraightToMerge']!=[] and self.Ids['StraightToMerge']==self.Ids['repkMF']:
                  self.Ids['repkF']=[]
                  self.Ids['repkMJ']=[]
             ###################### end special case 
             #print "result on "+target+"  ="+str(self.Ids[target])   +"\n"
             self.generateAllIds(target)
        #else:
          #print "no IDS found :( ... exiting!" 
          
    def buildTables(self):
        """
        This method produce the final results executing the queries: print*.
        This method requires the Ids dictionary to be filled. 
        """
        results=[]
        ## print only correct tables (the one which are in the order dictionary)
        keys=[]
        for key in self.Ids:
            if key in self.order.keys():
                keys.append(key)
                
        #print "KEYS="+ str(keys)
        # if the len(keys) is bigger then MAXDIM we execute multiple queries and merge the results
        for t in keys:
            resultList=[]
            origSql=getattr(self, 'print'+t[0].upper()+t[1:])
            n=1+ ( len(self.Ids[t]) // self.MAXDIM) 
            for j in range(1,n+1):
             ids=self.Ids[t][((j-1)*self.MAXDIM):(j*self.MAXDIM)]
             if len(ids)>0: 
               sql=origSql %(','.join(ids))
               partResult = self.dbi.processData(sql, {}, conn = self.conn,
                                      transaction = self.transaction)
               resultList+= self.formatDict(partResult)
            results.append( [{'tablename':self.tableNames[t]}]+ resultList)
        return results
     
     
    # this is the query executor for all the getIds queries!!
    def getIdsQuery(self,current, target,option=""):
      """
      This query produce the ids of the 'target' table starting from the 'current' ids [already done]
      """
      resultIds=[]
      origSql=getattr(self, 'get'+target[0].upper()+target[1:]+'IdsBy'+current[0].upper()+current[1:]+option)
      n=1+ ( len(self.Ids[current]) // self.MAXDIM) 
      #print " n== "+str(n)+ "  len="+str(len(self.Ids[currentIds]))
      for j in range(1,n+1):
          #print 'j=='+str(j)
          ids=self.Ids[current][((j-1)*self.MAXDIM):(j*self.MAXDIM)]
          if len(ids)>0: 
           sql=origSql %(','.join(ids))
           result = self.dbi.processData(sql, {}, conn = self.conn,
                                      transaction = self.transaction)
           resultList= self.format(result)
           resultIds +=  [str(object[0]) for object in resultList]
      return resultIds
                 
        
#################### choice of the order
    def strmExprGreaterThenBulks(self):
      """
      This method hold a special case: when the input is a streamer there are 2 options:
      * simple express-stremer tree
      * complete streamer-repack-reco-alco tree
      The decision is made according with the highest number of streamer_id processed between the ones with style='Bulk' or 'Express' 
      """
      #check express or repack/reco/alca layout!
      if self.vtype=='strm':
       try:
        sql= self.sqlStreamerExpress % self.value
        result = self.dbi.processData(sql, {}, conn = self.conn,
                                      transaction = self.transaction)
        expressDict=self.formatDict(result)[0]
        sql= self.sqlStreamerBulk % self.value
        result = self.dbi.processData(sql, {}, conn = self.conn,
                                      transaction = self.transaction)
        bulkDict=self.formatDict(result)[0]
        bulk=bulkDict['streamer_id']
        express=expressDict['streamer_id']
        #print " values: expr="+str(express)+ "  bulk="+str(bulk)
        if express>0:
          #print str(self.order)
          return True
        if bulk>0:
          return False
       except Exception,e :
         print  e
         pass
       return False

          
################ special methods (used by special cases)
    def deleteIds(self, index, forbidden):
        res=[]
        for i in self.Ids[index]:
            if i not in forbidden:
                res.append(i)
        self.Ids[index]=res      
      
    sqlStreamerExpress=""" SELECT
                count(*) as streamer_id
                from 
                streamer s
                INNER JOIN run_stream_style_assoc rssa ON (rssa.stream_id = s.stream_id) 
                where s.streamer_id = %s AND rssa.style_id = (SELECT id FROM processing_style WHERE name = 'Express' )"""
    sqlStreamerBulk= """ SELECT
                count(*) as streamer_id
                from 
                streamer s
                INNER JOIN run_stream_style_assoc rssa ON (rssa.stream_id = s.stream_id) 
                where s.streamer_id = %s AND rssa.style_id = (SELECT id FROM processing_style WHERE name = 'Bulk' )"""
##################################################################### IDS sql EXPR-STRM [8 queries]
    getExprJIdsByStrm = """SELECT DISTINCT wmbs_job.id
                           FROM wmbs_job
                           INNER JOIN wmbs_job_assoc ON
                             wmbs_job_assoc.job = wmbs_job.id AND
                             wmbs_job_assoc.fileid IN (%s)
                           """

    getExprFIdsByStrm = """SELECT DISTINCT wmbs_file_parent.child
                           FROM wmbs_file_parent
                           WHERE wmbs_file_parent.parent IN (%s)
                           """
  
    getExprMJIdsByExprF="""SELECT j.id
           FROM wmbs_job j 
               INNER JOIN wmbs_job_assoc ja ON (j.id = ja.job) 
               WHERE ja.fileid IN (%s)"""
               
    getExprMFIdsByExprF="""  SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_fileset_files fsf ON (f.id  = fsf.fileid)
INNER JOIN wmbs_fileset fs        ON (fs.id = fsf.fileset)
INNER JOIN wmbs_file_parent fp    ON (f.id  = fp.child)
WHERE
  fs.name      = 'ExpressDBSUploadable'
AND fp.parent IN (%s)"""

    getStrmIdsByExprJ = """SELECT wmbs_job_assoc.fileid
                           FROM wmbs_job_assoc
                           WHERE wmbs_job_assoc.job IN (%s)
                           """

    getStrmIdsByExprF = """SELECT DISTINCT wmbs_file_parent.parent
                           FROM wmbs_file_parent
                           WHERE wmbs_file_parent.child IN (%s)
                           """

    getExprMJIdsByExprMF="""SELECT  DISTINCT 
  j.id
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja       ON (j.id      = ja.job)
WHERE
  ja.job IN
  (SELECT
    job
  FROM
    wmbs_job_assoc
  INNER JOIN wmbs_file_parent ON (parent = fileid)
  WHERE
    child IN (%s)
  )"""
  
    getExprFIdsByExprMJ="""  SELECT DISTINCT f.id  
            FROM wmbs_file_details f  
            INNER JOIN wmbs_job_assoc ja ON (ja.fileid = f.id) WHERE ja.job IN (%s) """
	 
    getExprMFIdsByDQMJ="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_job_assoc ja              ON (ja.fileid          = f.id)
WHERE
 ja.job    IN (%s) """ 
    getDQMJIdsByExprMF="""SELECT  DISTINCT j.id
FROM  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id      = ja.job)
WHERE  ja.job IN
  (SELECT     job
  FROM    wmbs_job_assoc
  WHERE fileid IN (%s))
ORDER BY 1 DESC """
    getExprFIdsByDQMJ="""SELECT DISTINCT
 fp.parent
FROM
  wmbs_file_details f
INNER JOIN wmbs_job_assoc ja    ON (ja.fileid          = f.id)
INNER JOIN wmbs_file_parent fp  ON (fp.child=f.id)
WHERE
 ja.job    IN (%s) """
    getDQMJIdsByExprF=""" SELECT DISTINCT
   ja.job 
   FROM
    wmbs_job_assoc ja   
   INNER JOIN wmbs_file_details f  ON (ja.fileid          = f.id)
   INNER JOIN wmbs_file_parent  fp ON  (fp.child = f.id)
   WHERE fp.parent IN (%s) """
     
###################################################################### STREAMER
    printStrm = """SELECT streamer.streamer_id AS streamer_id,
                          wmbs_file_runlumi_map.lumi AS lumi_id,
                          wmbs_file_details.filesize AS filesize,
                          wmbs_file_details.events AS events,
                          stream.name AS stream,
                          wmbs_file_details.lfn AS lfn
                   FROM streamer
                   INNER JOIN wmbs_file_runlumi_map ON
                     wmbs_file_runlumi_map.fileid = streamer.streamer_id
                   INNER JOIN wmbs_file_details ON
                     wmbs_file_details.id = streamer.streamer_id
                   INNER JOIN stream ON
                     stream.id = streamer.stream_id
                   WHERE streamer.streamer_id IN (%s)
                   ORDER BY streamer.streamer_id DESC
                   """
####################################################################### EXPRESS OUTPUT queries
    printExprJ = """SELECT wmbs_job.id AS job_id,
                           wmbs_file_runlumi_map.run AS run_id,
                           wmbs_jobgroup.last_update AS def_time,
                           wmbs_job_state.name AS status,
                           COUNT(*) AS num_streamers
                    FROM wmbs_job
                    INNER JOIN wmbs_jobgroup ON
                      wmbs_jobgroup.id = wmbs_job.jobgroup
                    INNER JOIN wmbs_job_assoc ON
                      wmbs_job_assoc.job = wmbs_job.id
                    INNER JOIN wmbs_file_runlumi_map ON
                      wmbs_file_runlumi_map.fileid = wmbs_job_assoc.fileid
                    INNER JOIN wmbs_job_state ON
                      wmbs_job_state.id = wmbs_job.state
                    WHERE wmbs_job.id IN (%s)
                    GROUP BY wmbs_job.id,
                             wmbs_file_runlumi_map.run,
                             wmbs_jobgroup.last_update,
                             wmbs_job_state.name
                    ORDER BY wmbs_job.id DESC
                    """

    printExprF="""SELECT DISTINCT f.id, f.filesize, f.events, f.lfn  
            FROM wmbs_file_details f  
            INNER JOIN wmbs_fileset_files fsf ON (f.id = fsf.fileid)
            INNER JOIN wmbs_fileset fs ON (fs.id = fsf.fileset) 
            WHERE  fs.name = 'ExpressMergeable' and f.id IN (%s) 
            ORDER BY  1 DESC """
    
    printExprMJ="""SELECT DISTINCT
  j.id                      AS job_id,
  m.run                     AS run_id,
  j.state_time              AS def_time,
  COUNT(DISTINCT ja.fileid) AS inputfiles,
  js.name                   AS status
FROM
  wmbs_job j
INNER JOIN wmbs_job_state js       ON (j.state = js.id)
INNER JOIN wmbs_job_assoc ja       ON (j.id = ja.job)
INNER JOIN wmbs_file_details f     ON (f.id = ja.fileid)
INNER JOIN wmbs_file_runlumi_map m ON (f.id = m.fileid)
WHERE
  j.id IN (%s)
GROUP BY
  j.id,
  js.name,
  m.run,
  j.state_time
ORDER BY
  1 DESC"""
    

    printExprMF="""SELECT DISTINCT f.id, f.filesize, f.events, f.lfn  
            FROM wmbs_file_details f  
            INNER JOIN wmbs_file_runlumi_map m ON (f.id = m.fileid)
            INNER JOIN wmbs_fileset_files fsf ON (f.id = fsf.fileid)
            INNER JOIN wmbs_fileset fs ON (fs.id = fsf.fileset) 
            WHERE f.id IN (%s) and (fs.name = 'ExpressDBSUploadable' or fs.name='DQMenable') 
            ORDER BY  1 DESC """
	    
    printDQMJ="""SELECT
  j.id as job_id,
  m.run as run_id,
  j.state_time as def_time,
  COUNT(DISTINCT ja.fileid) as inputfiles,js.name as status,
  pd.name as dataset
FROM
   wmbs_job j
INNER JOIN  wmbs_job_assoc ja              ON (j.id      = ja.job)
INNER JOIN wmbs_job_state js               ON (j.state = js.id)
INNER JOIN  wmbs_file_details f            ON (ja.fileid = f.id)
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id = f.id)
INNER JOIN  dataset_path dp                ON (dp.id     = a.dataset_path_id)
INNER JOIN  primary_dataset pd             ON (pd.id     = dp.primary_dataset)
INNER JOIN  wmbs_file_runlumi_map m        ON (f.id      = m.fileid)
WHERE
  ja.job IN (%s)
GROUP BY
  j.id,
  js.name,
  m.run,
  j.state_time,
  pd.name
ORDER BY
  1 DESC """
    #printDQMF="""SELECT DISTINCT
  #f.id,
  #f.filesize,
  #f.events,
  #dt.name AS tier,
  #pd.name AS dataset,
  #f.lfn
#FROM
   #wmbs_file_details f
#INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
#INNER JOIN  dataset_path dp                ON (a.dataset_path_id  = dp.id)
#INNER JOIN  primary_dataset pd             ON (dp.primary_dataset = pd.id)
#INNER JOIN  data_tier dt                   ON (dp.data_tier       = dt.id)
#INNER JOIN  wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
#INNER JOIN  wmbs_fileset fs                ON (fs.id              = fsf.fileset)
#WHERE 
 #f.id   IN (%s  )
#ORDER BY
  #1 DESC """
#################################################################################################################### REPK-STRM IDS 
    getRepkJIdsByRepkF = """SELECT DISTINCT wmbs_job.id
                            FROM wmbs_job
                            INNER JOIN wmbs_job_assoc ON
                              wmbs_job_assoc.job = wmbs_job.id
                            INNER JOIN wmbs_file_parent ON
                              wmbs_file_parent.parent = wmbs_job_assoc.fileid AND
                              wmbs_file_parent.child IN (%s)
                            """

    getRepkJIdsByRepkMF=getRepkJIdsByRepkF #use this query with caution [only when other path to Repak Jobs has not worked]

    getRepkFIdsByStrm = """SELECT DISTINCT wmbs_file_parent.child
                           FROM wmbs_file_parent
                           WHERE wmbs_file_parent.parent IN (%s)
                           """

    getRepkJIdsByStrm = """SELECT DISTINCT wmbs_job.id
                           FROM wmbs_job
                           INNER JOIN wmbs_job_assoc ON
                             wmbs_job_assoc.job = wmbs_job.id AND
                             wmbs_job_assoc.fileid IN (%s)
                           """

    getStrmIdsByRepkJ = """SELECT wmbs_job_assoc.fileid
                           FROM wmbs_job_assoc
                           WHERE wmbs_job_assoc.job IN (%s)
                           """

    getRepkMJIdsByRepkF="""SELECT DISTINCT
  j.id
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id      = ja.job)
  WHERE ja.fileid IN (%s)
"""

    getRepkMFIdsByRepkF="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_file_parent fp            ON (f.id               = fp.child)
WHERE
  dt.name      = 'RAW'
AND fs.name    = 'DBSUploadable'
AND fp.parent IN (%s)"""

    getRepkFIdsByRepkMJ="""SELECT DISTINCT
  f.id
  FROM  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_job_assoc ja              ON (ja.fileid          = f.id)
WHERE
  dt.name   = 'RAW'
AND ja.job IN (%s)"""

    getRepkMJIdsByRepkMF="""SELECT  DISTINCT 
  j.id
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id      = ja.job)
WHERE
  ja.job IN
  (SELECT
    job
  FROM
    wmbs_job_assoc
  INNER JOIN wmbs_file_parent ON (parent = fileid)
  WHERE
    child IN (%s)
  )"""
  
    getRepkMFIdsByRepkFStraightToMerge="""WITH repackTemporaryFileIds AS
(SELECT f.id FROM
 wmbs_file_details f
 WHERE f.id IN (%s))

SELECT  DISTINCT  r.id FROM repackTemporaryFileIds r
MINUS
SELECT DISTINCT
 f.id
FROM
   wmbs_file_details f
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN  dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN  primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN  data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN  wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN  wmbs_fileset fs                ON (fs.id              = fsf.fileset)
WHERE
  dt.name   = 'RAW' AND fs.name = 'Mergeable'
AND f.id   IN (SELECT id FROM repackTemporaryFileIds)"""

  ################################################################################################### REPACK print

    printRepkJ = """SELECT wmbs_job.id AS job_id,
                           wmbs_file_runlumi_map.run AS run_id,
                           wmbs_jobgroup.last_update AS def_time,
                           wmbs_job_state.name AS status,
                           stream.name AS stream,
                           COUNT(*) AS num_streamers
                    FROM wmbs_job
                    INNER JOIN wmbs_jobgroup ON
                      wmbs_jobgroup.id = wmbs_job.jobgroup
                    INNER JOIN wmbs_job_assoc ON
                      wmbs_job_assoc.job = wmbs_job.id
                    INNER JOIN wmbs_file_runlumi_map ON
                      wmbs_file_runlumi_map.fileid = wmbs_job_assoc.fileid
                    INNER JOIN streamer ON
                      streamer.streamer_id = wmbs_job_assoc.fileid
                    INNER JOIN stream ON
                      stream.id = streamer.stream_id
                    INNER JOIN wmbs_job_state ON
                      wmbs_job_state.id = wmbs_job.state
                    WHERE wmbs_job.id IN (%s)
                    GROUP BY wmbs_job.id,
                             wmbs_file_runlumi_map.run,
                             wmbs_jobgroup.last_update,
                             wmbs_job_state.name,
                             stream.name
                    ORDER BY wmbs_job.id DESC
                    """
  
    printRepkF="""SELECT DISTINCT
  f.id, f.filesize,  f.events,  pd.name as dataset,  f.lfn
FROM
   wmbs_file_details f
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN  dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN  primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN  data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN  wmbs_file_runlumi_map m        ON (f.id               = m.fileid)
INNER JOIN  wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN  wmbs_fileset fs                ON (fs.id              = fsf.fileset)
WHERE
  dt.name   = 'RAW' AND fs.name = 'Mergeable'
AND f.id   IN (%s)
ORDER BY
  1 DESC"""
  
  
    printRepkMF="""SELECT DISTINCT
    f.id,
    f.filesize,
    f.events,
    pd.name as dataset,
    f.lfn
    FROM
    wmbs_file_details f
    INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
    INNER JOIN  dataset_path dp                ON (a.dataset_path_id  = dp.id)
    INNER JOIN  primary_dataset pd             ON (dp.primary_dataset = pd.id)
    INNER JOIN  data_tier dt                   ON (dp.data_tier       = dt.id)
    INNER JOIN  wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
    INNER JOIN  wmbs_fileset fs                ON (fs.id              = fsf.fileset)
    WHERE
    dt.name      = 'RAW'
    AND fs.name    = 'DBSUploadable'
    AND f.id IN (%s) 
    ORDER BY
    1 DESC """
  
    printRepkMJ="""SELECT  DISTINCT 
  j.id as job_id,
  m.run as run_id,
  COUNT(DISTINCT ja.fileid) as inputfiles,
  pd.name as dataset,
  js.name as status
FROM
   wmbs_job j
INNER JOIN  wmbs_job_assoc ja              ON (j.id      = ja.job)
INNER JOIN wmbs_job_state js               ON (j.state = js.id)
INNER JOIN  wmbs_file_details f            ON (ja.fileid = f.id)
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id = f.id)
INNER JOIN  dataset_path dp                ON (dp.id     = a.dataset_path_id)
INNER JOIN  primary_dataset pd             ON (pd.id     = dp.primary_dataset)
INNER JOIN  wmbs_file_runlumi_map m        ON (f.id      = m.fileid)
WHERE
  ja.job IN (%s)
GROUP BY j.id,js.name, m.run, pd.name
 """
############################################################################## RECO  IDs

    getRecoJIdsByRepkMF=getDQMJIdsByExprMF

    getRecoFIdsByRepkMF="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_file_parent fp            ON (f.id               = fp.child)
WHERE ((dt.name                                                              ='RECO'
AND fs.name                                                                  = 'Mergeable')
OR (dt.name                                                                  ='ALCARECO'
AND fs.name                                                                  = 'AlcaSkimmable')
OR (dt.name                                                                  ='AOD')
OR (dt.name                                                                  ='DQM'))
AND fp.parent                                                               IN (%s)
ORDER BY
  1 DESC """

    getRecoMJIdsByRecoF="""SELECT DISTINCT  j.id
FROM  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id      = ja.job)
INNER JOIN wmbs_file_details f            ON (ja.fileid = f.id)
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id = f.id)
INNER JOIN dataset_path dp                ON (dp.id     = a.dataset_path_id)
INNER JOIN primary_dataset pd             ON (pd.id     = dp.primary_dataset)
INNER JOIN data_tier dt                   ON (dt.id = dp.data_tier)
WHERE  
(dt.name      = 'RECO' OR dt.name      = 'AOD' OR dt.name      = 'DQM') 
AND 
ja.job IN
  (SELECT    job 
  FROM    wmbs_job_assoc
  WHERE   fileid IN (%s))
ORDER BY
  1 DESC """ 

    getRecoMFIdsByRecoF="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_file_parent fp            ON (f.id               = fp.child)
WHERE
  ((dt.name      = 'RECO'
AND fs.name    = 'DBSUploadable')
OR (dt.name                                                                  ='AOD')
OR (dt.name                                                                  ='DQM'))
AND fp.parent IN (%s)
ORDER BY
  1 DESC """
  
    getRepkMFIdsByRecoJ="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_job_assoc ja              ON (ja.fileid          = f.id)
WHERE
  dt.name   = 'RAW'
AND fs.name = 'DBSUploadable'
AND ja.job IN (%s)
ORDER BY
  1 DESC """
  
    getRecoJIdsByRecoF="""SELECT   DISTINCT  j.id
FROM  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id      = ja.job)
WHERE
  ja.job IN
  (SELECT     job
  FROM    wmbs_job_assoc
   INNER JOIN wmbs_file_parent fp ON (fp.parent = fileid)
   INNER JOIN wmbs_job_assoc ja ON (ja.fileid = fp.parent) 
   INNER JOIN wmbs_job_mask jm ON ( jm.job = ja.job ) 
   INNER JOIN wmbs_file_details fd ON ( fd.id = fp.child AND jm.firstevent = fd.first_event ) 
  WHERE
    child IN (%s)
  )
ORDER BY
  1 DESC
    """
    getRecoFIdsByRecoMJ="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_job_assoc ja              ON (ja.fileid          = f.id)
WHERE ((dt.name                             ='RECO'
AND fs.name                                = 'Mergeable')
OR (dt.name                                ='ALCARECO'
AND fs.name                                = 'AlcaSkimmable')
OR (dt.name                                                                  ='AOD')
OR (dt.name                                                                  ='DQM'))
AND ja.job                                 IN (%s)
ORDER BY
  1 DESC """
  
    getRecoFIdsByRecoMF="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_file_parent fp            ON (f.id               = fp.parent)
WHERE ((dt.name                                                              ='RECO'
AND fs.name                                                                  = 'Mergeable')
OR (dt.name                                                                  ='ALCARECO'
AND fs.name                                                                  = 'AlcaSkimmable')
OR (dt.name                                                                  ='AOD')
OR (dt.name                                                                  ='DQM'))
AND fp.child                                                                IN (%s)
ORDER BY
  1 DESC """
    getRecoFIdsByRecoJ="""
SELECT DISTINCT fp.child
FROM wmbs_file_parent fp 
INNER JOIN wmbs_job_assoc ja ON (ja.fileid = fp.parent) 
INNER JOIN wmbs_job_mask jm ON ( jm.job = ja.job ) 
INNER JOIN wmbs_file_details fd ON ( fd.id = fp.child AND jm.firstevent = fd.first_event ) 
WHERE ja.job IN (%s)
 """
    getRecoFIdsByAlcaJ=""" SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_job_assoc ja              ON (ja.fileid          = f.id)
WHERE (dt.name                                                               ='ALCARECO'
AND fs.name                                                                  = 'AlcaSkimmable')
AND ja.job                                                                  IN (%s)
ORDER BY
  1 DESC"""
#########################################################################################################3 RECO print


    printRecoF="""SELECT DISTINCT
  f.id,
  f.filesize,
  f.events,
  dt.name AS tier,
  pd.name AS dataset,
  f.lfn
FROM
   wmbs_file_details f
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN  dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN  primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN  data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN  wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN  wmbs_fileset fs                ON (fs.id              = fsf.fileset)
WHERE ((dt.name                                                              ='RECO'
AND fs.name                                                                  = 'Mergeable')
OR (dt.name                                                                  ='ALCARECO'
AND fs.name                                                                  = 'AlcaSkimmable')
OR (dt.name                                                                  ='AOD')
OR (dt.name                                                                  ='DQM'))
AND f.id                                                                    IN (%s)
ORDER BY
  1 DESC """
  
    printRecoJ="""SELECT
  j.id as job_id,
  m.run as run_id,
  j.state_time as def_time,
  COUNT(DISTINCT ja.fileid) as inputfiles,
  pd.name as dataset,
  js.name as status
FROM
   wmbs_job j
INNER JOIN  wmbs_job_assoc ja              ON (j.id      = ja.job)
INNER JOIN wmbs_job_state js               ON (j.state = js.id)
INNER JOIN  wmbs_file_details f            ON (ja.fileid = f.id)
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id = f.id)
INNER JOIN  dataset_path dp                ON (dp.id     = a.dataset_path_id)
INNER JOIN  primary_dataset pd             ON (pd.id     = dp.primary_dataset)
INNER JOIN  wmbs_file_runlumi_map m        ON (f.id      = m.fileid)
WHERE
  ja.job IN (%s)
GROUP BY
  j.id,
  js.name,
  m.run,
  j.state_time,
  pd.name
ORDER BY
  1 DESC """
    printRecoMJ=""" SELECT
  j.id as job_id,
  m.run as run_id,
  j.state_time as def_time,
  dt.name AS tier,
  COUNT(DISTINCT ja.fileid) as inputfiles,
  pd.name as dataset,
  js.name as status
FROM
   wmbs_job j
INNER JOIN  wmbs_job_assoc ja              ON (j.id      = ja.job)
INNER JOIN wmbs_job_state js               ON (j.state = js.id)
INNER JOIN  wmbs_file_details f            ON (ja.fileid = f.id)
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id = f.id)
INNER JOIN  dataset_path dp                ON (dp.id     = a.dataset_path_id)
INNER JOIN  data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN  primary_dataset pd             ON (pd.id     = dp.primary_dataset)
INNER JOIN  wmbs_file_runlumi_map m        ON (f.id      = m.fileid)
WHERE
  ja.job IN (%s)
GROUP BY
  j.id,
  js.name,
  m.run,
  state_time,
  dt.name,
  pd.name
ORDER BY
  1 DESC """
    printRecoMF=""" SELECT DISTINCT
  f.id,
  f.filesize,
  f.events,
  dt.name AS tier,
  pd.name as dataset,
  f.lfn
FROM
   wmbs_file_details f
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN  dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN  primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN  data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN  wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN  wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN  wmbs_file_parent fp            ON (f.id               = fp.child)
WHERE
  ((dt.name      = 'RECO'
AND fs.name    = 'DBSUploadable') 
OR (dt.name      ='DQM')
OR (dt.name      ='AOD'))
AND f.id IN (%s)
ORDER BY
  1 DESC"""
  
############################################################################################### ALCA IDS
    getAlcaJIdsByRecoF="""SELECT  DISTINCT 
  j.id
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id                 = ja.job)
INNER JOIN wmbs_file_details f            ON (ja.fileid            = f.id)
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (dp.id                = a.dataset_path_id)
INNER JOIN primary_dataset pd             ON (pd.id                = dp.primary_dataset)
INNER JOIN wmbs_file_runlumi_map m        ON (f.id                 = m.fileid)
INNER JOIN data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id                 = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id                = fsf.fileset)
WHERE
  ja.job IN
  ( SELECT job FROM wmbs_job_assoc WHERE fileid IN (%s)
  )
AND dt.name ='ALCARECO'
AND fs.name = 'AlcaSkimmable'
ORDER BY
  1 DESC """
    getAlcaJIdsByAlcaF="""SELECT  DISTINCT 
  j.id
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id                 = ja.job)
WHERE
  ja.job IN
  (SELECT
    job
  FROM
    wmbs_job_assoc
  INNER JOIN wmbs_file_parent ON (parent = fileid)
  WHERE
    child IN (%s)
  )
ORDER BY
  1 DESC """
    getAlcaFIdsByRecoF="""SELECT DISTINCT
  f.id
FROM
 wmbs_file_details f
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN  dataset_path dp                ON (a.dataset_path_id    = dp.id)
INNER JOIN  primary_dataset pd             ON (dp.primary_dataset   = pd.id)
INNER JOIN  data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN  wmbs_fileset_files fsf         ON (f.id                 = fsf.fileid)
INNER JOIN  wmbs_fileset fs                ON (fs.id                = fsf.fileset)
INNER JOIN  processed_dataset pds          ON (dp.processed_dataset = pds.id)
INNER JOIN  wmbs_file_parent fp            ON (f.id                 = fp.child)
WHERE fp.parent IN (%s) AND
 dt.name   = 'ALCARECO'
AND fs.name = 'Mergeable'
ORDER BY
  1 DESC"""

    getAlcaMJIdsByAlcaF="""SELECT  DISTINCT 
  j.id
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id                 = ja.job)
WHERE
  ja.job IN
  (SELECT
    job
  FROM
    wmbs_job_assoc
  WHERE
    fileid IN (%s)
  )
ORDER BY
  1 DESC """
    getAlcaMFIdsByAlcaF="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id    = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset   = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id                 = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id                = fsf.fileset)
INNER JOIN wmbs_file_parent fp            ON (f.id                 = fp.child)
WHERE
  dt.name      = 'ALCARECO'
AND fs.name    = 'DBSUploadable'
AND fp.parent IN (%s)
ORDER BY
  1 DESC """
    getAlcaFIdsByAlcaJ="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id  = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier       = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id              = fsf.fileset)
INNER JOIN wmbs_job_assoc ja              ON (ja.fileid          = f.id)
WHERE (dt.name                                                               ='ALCARECO'
AND fs.name                                                                  = 'AlcaSkimmable')
AND ja.job                                                                  IN (%s)
ORDER BY
  1 DESC """
    getAlcaFIdsByAlcaMJ="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id    = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset   = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN wmbs_job_assoc ja              ON (ja.fileid            = f.id)
WHERE
  dt.name   = 'ALCARECO'
AND ja.job IN (%s)
ORDER BY
  1 DESC """
    getAlcaFIdsByAlcaMF="""SELECT DISTINCT
  f.id
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id    = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset   = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id                 = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id                = fsf.fileset)
INNER JOIN wmbs_file_parent fp            ON (f.id                 = fp.parent)
WHERE
  dt.name     = 'ALCARECO'
AND fs.name   = 'Mergeable'
AND fp.child IN (%s)
ORDER BY
  1 DESC """
  
    getAlcaMJIdsByAlcaMF="""SELECT distinct
  j.id
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id                 = ja.job)
INNER JOIN wmbs_file_details f            ON (ja.fileid            = f.id)
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (dp.id                = a.dataset_path_id)
INNER JOIN primary_dataset pd             ON (pd.id                = dp.primary_dataset)
INNER JOIN wmbs_file_runlumi_map m        ON (f.id                 = m.fileid)
INNER JOIN processed_dataset pds          ON (dp.processed_dataset = pds.id)
WHERE
  ja.job IN
  (SELECT
    job
  FROM
    wmbs_job_assoc
  INNER JOIN wmbs_file_parent ON (parent = fileid)
  WHERE
    child IN (%s)
  )
ORDER BY
  1 DESC"""
  
  ######################################################################################################## ALCA print
  
    printAlcaMF=""" SELECT DISTINCT
  f.id,
  f.filesize,
  f.events,
  pd.name as dataset,
  f.lfn,
  pds.name AS skim
FROM
  wmbs_file_details f
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (a.dataset_path_id    = dp.id)
INNER JOIN primary_dataset pd             ON (dp.primary_dataset   = pd.id)
INNER JOIN data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id                 = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id                = fsf.fileset)
INNER JOIN wmbs_file_parent fp            ON (f.id                 = fp.child)
INNER JOIN processed_dataset pds          ON (dp.processed_dataset = pds.id)
WHERE
  dt.name      = 'ALCARECO'
AND fs.name    = 'DBSUploadable'
AND f.id IN (%s)
ORDER BY
  1 DESC"""
    printAlcaF=""" SELECT DISTINCT
  f.id,
  f.filesize,
  f.events,
  pd.name as dataset,
  f.lfn,
  pds.name AS skim
FROM
   wmbs_file_details f
INNER JOIN  wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN  dataset_path dp                ON (a.dataset_path_id    = dp.id)
INNER JOIN  primary_dataset pd             ON (dp.primary_dataset   = pd.id)
INNER JOIN  data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN  wmbs_fileset_files fsf         ON (f.id                 = fsf.fileid)
INNER JOIN  wmbs_fileset fs                ON (fs.id                = fsf.fileset)
INNER JOIN  processed_dataset pds          ON (dp.processed_dataset = pds.id)
WHERE
  dt.name   = 'ALCARECO'
AND fs.name = 'Mergeable'
AND f.id   IN (%s)
ORDER BY
  1 DESC"""
  
  
  
    printAlcaJ=""" SELECT  DISTINCT 
  j.id as job_id,
  m.run as run_id,
  j.state_time as def_time,
  COUNT(DISTINCT ja.fileid) as inputfiles,
  pd.name as dataset,
  js.name as status
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id                 = ja.job)
INNER JOIN wmbs_job_state js              ON (j.state              = js.id)
INNER JOIN wmbs_file_details f            ON (ja.fileid            = f.id)
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (dp.id                = a.dataset_path_id)
INNER JOIN primary_dataset pd             ON (pd.id                = dp.primary_dataset)
INNER JOIN wmbs_file_runlumi_map m        ON (f.id                 = m.fileid)
INNER JOIN data_tier dt                   ON (dp.data_tier         = dt.id)
INNER JOIN wmbs_fileset_files fsf         ON (f.id                 = fsf.fileid)
INNER JOIN wmbs_fileset fs                ON (fs.id                = fsf.fileset)
INNER JOIN processed_dataset PROC         ON (dp.processed_dataset = proc.id)
WHERE
  ja.job IN (%s)
AND dt.name ='ALCARECO'
AND fs.name = 'AlcaSkimmable'
GROUP BY
  j.id,
  js.name,
  m.run,
  j.state_time,
  pd.name,
  proc.name
ORDER BY
  1 DESC"""
    
    printAlcaMJ=""" SELECT  DISTINCT 
  j.id as job_id,
  m.run as run_id,
  j.state_time as def_time,
  COUNT(DISTINCT ja.fileid) as inputfiles,
  pd.name as dataset,
  pds.name AS skim,
  js.name as status
FROM
  wmbs_job j
INNER JOIN wmbs_job_assoc ja              ON (j.id                 = ja.job)
INNER JOIN wmbs_job_state js              ON (j.state              = js.id)
INNER JOIN wmbs_file_details f            ON (ja.fileid            = f.id)
INNER JOIN wmbs_file_dataset_path_assoc a ON (a.file_id            = f.id)
INNER JOIN dataset_path dp                ON (dp.id                = a.dataset_path_id)
INNER JOIN primary_dataset pd             ON (pd.id                = dp.primary_dataset)
INNER JOIN wmbs_file_runlumi_map m        ON (f.id                 = m.fileid)
INNER JOIN processed_dataset pds          ON (dp.processed_dataset = pds.id)
WHERE
  ja.job IN (%s)
GROUP BY
  j.id,
  js.name,
  m.run,
  j.state_time,
  pd.name,
  pds.name
ORDER BY
  1 DESC"""
  
