#!/usr/bin/env python
"""
_Information on the AlcaReco configuration optionally filtered by run and dataset_
"""

from WMCore.Database.DBFormatter import DBFormatter

class AlcaDatasetConfig(DBFormatter):
   
   sql = """SELECT ac.run_id AS run,
                   ac.do_alca,
                   ac.proc_version,
                   ac.pset_hash,
                   ac.branch_hash,
                   ac.config_url,
                   sw.name AS cmssw_version,
                   ds.name AS primary_dataset
            FROM alca_config ac
            INNER JOIN cmssw_version sw ON sw.id = ac.cmssw_version_id
            INNER JOIN primary_dataset ds ON ds.id = ac.primary_dataset_id
            WHERE %s %s
            """
   sqlWhereWithRun="ac.run_id = :run"
   sqlWhereWithoutRun="ac.run_id = (select max(run_id) from alca_config)"
   sqlWhereOptionDataset="AND ds.name = :dataset"

   def execute(self, run = None, dataset = None, conn = None, transaction = False):
        """
        _execute_

        Execute the SQL 
        """
        if run and dataset:

           self.sql = self.sql % (self.sqlWhereWithRun, self.sqlWhereOptionDataset)

           if type(run) != list:
              run = [run]
           if type(dataset) != list:
              dataset = [dataset]

           bindVars = []
           for runElem in run:
              for datasetElem in dataset:
                 bindVars.append( { "run" : runElem,
                                    "dataset" : datasetElem } )

        elif run:

           self.sql = self.sql % (self.sqlWhereWithRun, '')

           if type(run) != list:
              run = [run]

           bindVars = []
           for runElem in run:
               bindVars.append( { "run" : runElem } )

        elif dataset: 

           self.sql = self.sql % (self.sqlWhereWithoutRun, self.sqlWhereOptionDataset)

           if type(dataset) != list:
              dataset = [dataset]

           for datasetElem in dataset:
                 bindVars.append( { "dataset" : datasetElem } )

        else:

           self.sql = self.sql % (self.sqlWhereWithoutRun, '')
           bindVars = {}
           
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
        
        return self.formatDict(result)  
