#!/usr/bin/env python
"""
_General information on the configuration, this query is useful to show in 1 table all the configuration information _
"""

from WMCore.Database.DBFormatter import DBFormatter

class GeneralConfig(DBFormatter):
     
    sql="""SELECT distinct
      sub.ds_dataset as dataset,
      CASE sub.ro_reco WHEN 0 THEN 'Disabled' WHEN 1 THEN 'Enabled'
      END ro_do_reco,
      sub.ro_cmssw_version,
      sub.ro_global_tag,
      sub.ro_config_url,
      sub.ro_proc_version,
      CASE sub.al_alcaskim WHEN 0 THEN 'Disabled' WHEN 1 THEN 'Enabled'
      END al_do_alca,
      sub.al_cmssw_version,
      sub.al_config_url,
      sub.al_proc_version
    FROM
      (SELECT
        ds.name ds_dataset,
        ro.do_reco ro_reco,
        sw1.name ro_cmssw_version,
        ro.global_tag ro_global_tag,
        ro.config_url ro_config_url,
        ro.proc_version ro_proc_version,
        al.do_alca al_alcaskim,
        sw2.name al_cmssw_version,
        al.config_url al_config_url,
        al.proc_version al_proc_version
      FROM
          reco_config ro
        INNER JOIN  alca_config al ON al.run_id = ro.run_id
        INNER JOIN cmssw_version sw1 ON sw1.id = ro.cmssw_version_id
        INNER JOIN cmssw_version sw2 ON sw2.id = al.cmssw_version_id
        INNER JOIN primary_dataset ds ON ds.id = ro.primary_dataset_id
      WHERE
        ro.run_id               = :run
      AND ro.primary_dataset_id = al.primary_dataset_id
      ) sub  ORDER BY
        1 ASC"""

    def execute(self, run, conn = None, transaction = False):
        """
        _execute_

        Execute the SQL 
        """
        if type(run) != list:
            run = [run]

        bindVars = []
        for runElem in run:
            bindVars.append( { "run" : runElem } )

        if len(bindVars) > 0:

            result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                          transaction = transaction)

        else:

            result = []

        return self.formatDict(result)

