#!/usr/bin/env python
"""
_Information on the Reco configuration optionally filtered by run and dataset_


"""

from WMCore.Database.DBFormatter import DBFormatter

class RecoDatasetConfig(DBFormatter):
   
   sql = """SELECT rc.run_id AS run,
                   rc.do_reco,
                   rc.reco_split,
                   rc.proc_version,
                   rc.global_tag,
                   rc.pset_hash,
                   rc.branch_hash,
                   rc.config_url,
                   sw.name AS cmssw_version,
                   ds.name AS primary_dataset,
		   es.scenario as scenario
            FROM reco_config rc
            INNER JOIN cmssw_version sw ON sw.id = rc.cmssw_version_id
            INNER JOIN primary_dataset ds ON ds.id = rc.primary_dataset_id
	    INNER JOIN scenario_config sc ON (rc.run_id = sc.run_id AND sc.primary_dataset_id = ds.id )
            INNER JOIN event_scenario es ON (sc.scenario_id = es.id)
            WHERE %s %s
            """
   sqlWhereWithRun="rc.run_id = :run"
   sqlWhereWithoutRun="rc.run_id = (select max(run_id) from reco_config)"
   sqlWhereOptionDataset="AND ds.name = :dataset"

   def execute(self, run = None, dataset = None, conn = None, transaction = False):
        """
        _execute_

        Execute the SQL 
        """
        if run and dataset:

           self.sql = self.sql % (self.sqlWhereWithRun, self.sqlWhereOptionDataset)

           if type(run) != list:
              run = [run]
           if type(dataset) != list:
              dataset = [dataset]

           bindVars = []
           for runElem in run:
              for datasetElem in dataset:
                 bindVars.append( { "run" : runElem,
                                    "dataset" : datasetElem } )

        elif run:

           self.sql = self.sql % (self.sqlWhereWithRun, '')

           if type(run) != list:
              run = [run]

           bindVars = []
           for runElem in run:
               bindVars.append( { "run" : runElem } )

        elif dataset: 

           self.sql = self.sql % (self.sqlWhereWithoutRun, self.sqlWhereOptionDataset)

           if type(dataset) != list:
              dataset = [dataset]

           for datasetElem in dataset:
                 bindVars.append( { "dataset" : datasetElem } )

        else:

           self.sql = self.sql % (self.sqlWhereWithoutRun, '')
           bindVars = {}
           
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
        
        return self.formatDict(result)  
