#!/usr/bin/env python
"""
_LastFilesSummary_

short information about the last files

T0Mon: this class is used for all the tier plots
"""

from WMCore.Database.DBFormatter import DBFormatter

class LastFilesSummary(DBFormatter):
   
    def execute(self, stime, etime, tier, conn = None, transaction = False):
        """
        create correct sql query and execute it

        """
        try:
            stime = int(stime)
        except ValueError:
            stime = 0

        try:
            etime = int(etime)
        except ValueError:
            etime = 0

        try:
            tier = str(tier)
        except ValueError:
            tier = None
            
        if len(tier)==0: 
          tier=None
         
        bindVars = {}

        if stime > 0 and etime > 0:
            bindVars.update( { 'STIME' : stime,
                               'ETIME' : etime } )
        else:
            return {"Error" : "wrong time"}

        if tier != None:
            sqlDatatierCheck = """AND dp.data_tier = (SELECT id FROM data_tier WHERE name = :DATATIER)"""
            bindVars.update( { 'DATATIER' : tier } )
        else:
            sqlDatatierCheck = ""

        sql = """SELECT DISTINCT f.id AS id,
                                 f.filesize AS filesize,
                                 j.state_time AS time,
                                 f.events AS events,
                                 pd.name AS dataset,
                                 CASE
                                   WHEN s.name = 'A' OR s.name = 'Express' THEN s.name 
                                   ELSE 'others'
                                 END AS stream
                 FROM wmbs_file_details f
                 INNER JOIN wmbs_file_dataset_path_assoc a ON a.file_id = f.id
                 INNER JOIN dataset_path dp ON a.dataset_path_id = dp.id
                 INNER JOIN primary_dataset pd ON dp.primary_dataset = pd.id
                 INNER JOIN wmbs_job_assoc ja ON ja.fileid = f.id
                 INNER JOIN wmbs_job j ON j.id = ja.job
                 INNER JOIN dataset_run_stream_assoc dr ON dr.primary_dataset_id = pd.id
                 INNER JOIN stream s ON s.id = dr.stream_id
                 WHERE j.state_time > :STIME
                 AND j.state_time < :ETIME
                 %s
                 ORDER BY j.state_time DESC
                 """ % sqlDatatierCheck
        
        result = self.dbi.processData(sql, bindVars, conn = conn,
                                      transaction = transaction)
        
        return self.formatDict(result) 
 
