#!/usr/bin/env python
"""
_Information on repack files by run__

T0Mon: this class is used in the run page [repack file table]
"""

from T0.DAS.Database.Oracle.LongResultQuery import LongResultQuery 

class RepackFilesByRun(LongResultQuery):
   sql="""SELECT DISTINCT  \
  f.id, f.filesize, f.events, pd.name as dataset,  f.lfn, m.run  \
FROM   wmbs_file_details f  \
INNER JOIN   wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)  \
INNER JOIN   dataset_path dp                ON (a.dataset_path_id  = dp.id)  \
INNER JOIN   primary_dataset pd             ON (dp.primary_dataset = pd.id)  \
INNER JOIN   data_tier dt                   ON (dp.data_tier       = dt.id)  \
INNER JOIN   wmbs_file_runlumi_map m        ON (f.id               = m.fileid)  \
INNER JOIN   wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)  \
INNER JOIN   wmbs_fileset fs                ON (fs.id              = fsf.fileset)  \
WHERE  \
  dt.name   = %s  \
AND m.run   = %s  \
AND fs.name = %s  \
ORDER BY  \
  1 DESC """
    
   sqlDataTier="'RAW'"
   sqlRun=":run"
   sqlMaxrun="(SELECT max(run_id) AS run FROM run)"
   sqlFileSet="'DBSUploadable'"
   
   
   def buildQuery(self):
      self.sql=self.sql % (self.sqlDataTier,self.sqlRun,self.sqlFileSet)
    
   def execute(self, run,uplimit,downlimit, conn = None, transaction = False):
        bindVars={}
        try:
          if int(run)>0:
           #self.sql=self.sql % (self.sqlDataTier,self.sqlRun,self.sqlFileSet)
           self.buildQuery()
           bindVars = {"run": run,"uplimit":uplimit,"downlimit":downlimit}
          else: 
            raise Exception('zeroRun')
        except Exception:
            bindVars={"uplimit":uplimit,"downlimit":downlimit}
            self.sqlRun=self.sqlMaxrun
            self.buildQuery()
        #print self.sql
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
        return self.formatDict(result) 
#######################################################################################################
from WMCore.Database.DBFormatter import DBFormatter
class RepackFilesByRun_count(DBFormatter):

   sql="""SELECT COUNT(DISTINCT  f.id)
FROM   wmbs_file_details f  
INNER JOIN   wmbs_file_dataset_path_assoc a ON (a.file_id          = f.id)  
INNER JOIN   dataset_path dp                ON (a.dataset_path_id  = dp.id)  
INNER JOIN   primary_dataset pd             ON (dp.primary_dataset = pd.id)  
INNER JOIN   data_tier dt                   ON (dp.data_tier       = dt.id)  
INNER JOIN   wmbs_file_runlumi_map m        ON (f.id               = m.fileid)  
INNER JOIN   wmbs_fileset_files fsf         ON (f.id               = fsf.fileid)  
INNER JOIN   wmbs_fileset fs                ON (fs.id              = fsf.fileset)  
WHERE  
  dt.name   = %s  
AND m.run   = %s  
AND fs.name = %s
"""
    
   sqlDataTier="'RAW'"
   sqlRun=":run"
   sqlMaxrun="(SELECT max(run_id) AS run FROM run)"
   sqlFileSet="'DBSUploadable'"
   
   
   def buildQuery(self):
      self.sql=self.sql % (self.sqlDataTier,self.sqlRun,self.sqlFileSet)
    
   def execute(self, run, conn = None, transaction = False):
        bindVars={}
        try:
          if int(run)>0:
           #self.sql=self.sql % (self.sqlDataTier,self.sqlRun,self.sqlFileSet)
           self.buildQuery()
           bindVars = {"run": run}
          else: 
            raise Exception('zeroRun')
        except Exception:
            bindVars={}
            self.sqlRun=self.sqlMaxrun
            self.buildQuery()
        #print self.sql
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
        return self.format(result) 