#!/usr/bin/env python
"""
_Information on all the active Reco jobs _
T0Mon: this class is used in the front page
"""

from T0.DAS.Database.Oracle.Jobs.LastAcquiredRepackMerge import LastAcquiredRepackMerge
from WMCore.Database.DBFormatter import DBFormatter

class LastAcquiredReco(LastAcquiredRepackMerge):
  sqlFileSet="'Reconstructable'"
  sql=""" SELECT DISTINCT
  wmbs_job.id                             AS job_id,
  wmbs_file_runlumi_map.run               AS run_id,
  wmbs_job.state_time                     AS state_time,
  COUNT(DISTINCT( wmbs_job_assoc.fileid)) AS inputfiles,
  primary_dataset.name                    AS dataset
FROM
  wmbs_job
JOIN wmbs_jobgroup                ON wmbs_job.jobgroup                            = wmbs_jobgroup.id
INNER JOIN wmbs_job_state         ON wmbs_job.state                               = wmbs_job_state.id 
JOIN wmbs_job_assoc               ON wmbs_job.id                                  = wmbs_job_assoc.job
JOIN wmbs_file_details            ON wmbs_file_details.id                         = wmbs_job_assoc.fileid
JOIN wmbs_file_runlumi_map        ON wmbs_file_details.id                         = wmbs_file_runlumi_map.fileid
JOIN wmbs_file_dataset_path_assoc ON wmbs_file_details.id                         = wmbs_file_dataset_path_assoc.file_id
JOIN dataset_path                 ON wmbs_file_dataset_path_assoc.dataset_path_id = dataset_path.id
JOIN primary_dataset              ON primary_dataset.id                           = dataset_path.primary_dataset
WHERE
   wmbs_jobgroup.subscription =   ( SELECT id FROM  wmbs_fileset WHERE name = %s)
   AND wmbs_job_state.name!='cleanout'
GROUP BY
  wmbs_job.id,
  wmbs_job.state_time,
  wmbs_file_runlumi_map.run,
  primary_dataset.name
ORDER BY
  wmbs_job.id DESC"""
   
  def execute(self, uplimit,downlimit, conn = None, transaction = False):
        self.sql=self.sql %(self.sqlFileSet)
        bindVars = {"uplimit": uplimit,"downlimit": downlimit}
        #print self.sql + "   "+ str(bindVars)
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
        
        return self.formatDict(result) 

#################################################################
class LastAcquiredReco_count(DBFormatter):
  sqlFileSet="'Reconstructable'"
  sql="""SELECT COUNT( DISTINCT wmbs_job.id)
FROM
  wmbs_job
JOIN wmbs_jobgroup                ON wmbs_job.jobgroup                            = wmbs_jobgroup.id
INNER JOIN wmbs_job_state         ON wmbs_job.state                               = wmbs_job_state.id 
WHERE
   wmbs_jobgroup.subscription =   ( SELECT id FROM  wmbs_fileset WHERE name = %s)
   AND wmbs_job_state.name!='cleanout' """
  def execute(self,  conn = None, transaction = False):
      self.sql=self.sql %(self.sqlFileSet)
      result = self.dbi.processData(self.sql, {}, conn = conn,
                                      transaction = transaction)
      return self.format(result)
    