#!/usr/bin/env python
"""
_Information on all the active jobs (and their associated streams and streamers)_

T0Mon: this class is used in the front page
"""
from T0.DAS.Database.Oracle.LongResultQuery import LongResultQuery 

class LastAcquiredRepackMerge(LongResultQuery):
   
   datatier="RAW"
   job_state="cleanout" # instead of the 'created' I select the non 'cleanout'
   fileset="Mergeable"
  
   sql="""   SELECT  \
           wmbs_job.id                            AS  job_id,  \
           wmbs_file_runlumi_map.run              AS run_id,  \
           wmbs_job.state_time                    AS state_time,  \
          COUNT(DISTINCT( wmbs_job_assoc.fileid)) AS inputfiles,  \
           primary_dataset.name                   AS dataset  \
        FROM         wmbs_job  \
        JOIN  wmbs_jobgroup                ON  wmbs_job.jobgroup                            =  wmbs_jobgroup.id  \
        JOIN  wmbs_job_assoc               ON  wmbs_job.id                                  =  wmbs_job_assoc.job  \
        JOIN  wmbs_file_details            ON  wmbs_file_details.id                         =  wmbs_job_assoc.fileid  \
        JOIN  wmbs_file_runlumi_map        ON  wmbs_file_details.id                         =  wmbs_file_runlumi_map.fileid  \
        JOIN  wmbs_file_dataset_path_assoc ON  wmbs_file_details.id                         =  wmbs_file_dataset_path_assoc.file_id  \
        JOIN  dataset_path                 ON  wmbs_file_dataset_path_assoc.dataset_path_id =  dataset_path.id  \
        JOIN  primary_dataset              ON  primary_dataset.id                           =  dataset_path.primary_dataset  \
        WHERE  dataset_path.data_tier =   \
          ( SELECT  data_tier.id   FROM  data_tier  \
            WHERE    data_tier.name = :datatier)  \
        AND   wmbs_jobgroup.subscription =  \
          ( SELECT wmbs_subscription.id   FROM wmbs_subscription  \
            WHERE wmbs_subscription.fileset =  \
              (  SELECT wmbs_fileset.id  FROM  wmbs_fileset  \
                WHERE    wmbs_fileset.name = :fileset) )
      AND wmbs_job.state !=  \
          (   SELECT   wmbs_job_state.id   FROM      wmbs_job_state  \
            WHERE   wmbs_job_state.name = :job_state )  \
        GROUP BY   \
           wmbs_job.id,  \
           wmbs_job.state_time,  \
           wmbs_file_runlumi_map.run,  \
           primary_dataset.name  \
        ORDER BY  \
           wmbs_job.id DESC  \
"""
                
   def execute(self, uplimit,downlimit, conn = None, transaction = False):
        bindVars = {"uplimit": uplimit,"downlimit": downlimit, "datatier": self.datatier,"job_state": self.job_state,"fileset": self.fileset}
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
        
        return self.formatDict(result) 
   
   
###########################################################################
from WMCore.Database.DBFormatter import DBFormatter

class LastAcquiredRepackMerge_count(DBFormatter):
  datatier="RAW"
  job_state="cleanout" # instead of the 'created' I select the non 'cleanout'
  fileset="Mergeable"
  sql="""   SELECT COUNT(DISTINCT wmbs_job.id)
        FROM         wmbs_job 
        JOIN  wmbs_jobgroup                ON  wmbs_job.jobgroup                            =  wmbs_jobgroup.id 
        JOIN  wmbs_job_assoc               ON  wmbs_job.id                                  =  wmbs_job_assoc.job 
        JOIN  wmbs_file_details            ON  wmbs_file_details.id                         =  wmbs_job_assoc.fileid 
        JOIN  wmbs_file_dataset_path_assoc ON  wmbs_file_details.id                         =  wmbs_file_dataset_path_assoc.file_id 
        JOIN  dataset_path                 ON  wmbs_file_dataset_path_assoc.dataset_path_id =  dataset_path.id 
        WHERE  dataset_path.data_tier =  
          ( SELECT  data_tier.id   FROM  data_tier 
            WHERE    data_tier.name = :datatier) 
        AND   wmbs_jobgroup.subscription = 
          ( SELECT wmbs_subscription.id   FROM wmbs_subscription 
            WHERE wmbs_subscription.fileset = 
              (  SELECT wmbs_fileset.id  FROM  wmbs_fileset 
                WHERE    wmbs_fileset.name = :fileset) )
      AND wmbs_job.state != 
          (   SELECT   wmbs_job_state.id   FROM      wmbs_job_state 
            WHERE   wmbs_job_state.name = :job_state )  """
  def execute(self,  conn = None, transaction = False):
      bindVars = {"datatier": self.datatier,"job_state": self.job_state,"fileset": self.fileset}
      result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
      return self.format(result)