#!/usr/bin/env python
"""
_LastAcquiredStreamerJobs_

Returns information on acquired jobs (Express or Repack)

T0Mon: this class is used in the front page
"""

from T0.DAS.Database.Oracle.LongResultQuery import LongResultQuery 
from WMCore.Database.DBFormatter import DBFormatter

allowedFilesets= ['Repack','Express']

class LastAcquiredStreamerJobs(LongResultQuery):
  
   #FIXME: drop the LongResultQuery
   #       find MAX(job_id) and fetch last X rows

   sql = """SELECT wmbs_job.id AS job_id,
                   wmbs_jobgroup.last_update AS def_time,
                   streamer.run_id AS run_id,
                   stream.name AS stream,
                   COUNT(*) AS num_streamers
            FROM wmbs_job
            INNER JOIN wmbs_jobgroup ON
              wmbs_jobgroup.id = wmbs_job.jobgroup AND
              wmbs_jobgroup.subscription = (SELECT id FROM wmbs_subscription
                                            WHERE fileset = (SELECT id FROM wmbs_fileset
                                                             WHERE name = :fileset))
            INNER JOIN wmbs_job_assoc ON
              wmbs_job_assoc.job = wmbs_job.id
            INNER JOIN streamer ON
              streamer.streamer_id = wmbs_job_assoc.fileid
            INNER JOIN stream ON
              stream.id = streamer.stream_id
            WHERE wmbs_job.state IN (
              SELECT id FROM wmbs_job_state
              WHERE name IN ('new', 'created', 'executing')
            )
            GROUP BY wmbs_job.id,
                     wmbs_jobgroup.last_update,
                     streamer.run_id,
                     stream.name
            ORDER BY wmbs_job.id DESC
            """

   def execute(self,fileset, uplimit, downlimit, conn = None, transaction = False):
        bindVars = { 'uplimit' : uplimit,
                     'downlimit' : downlimit }
                     
        global allowedFilesets
        try: 
          index= allowedFilesets.index(fileset.lower().capitalize())
          bindVars.update({'fileset':allowedFilesets[index]})
        except (IndexError,ValueError):
          return { "Error" : "wrong fileset name", "hint" : allowedFilesets }
        
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)
        return self.formatDict(result)

class LastAcquiredStreamerJobs_count(DBFormatter):

   sql = """SELECT COUNT(*) AS count
            FROM wmbs_job
            INNER JOIN wmbs_jobgroup ON
              wmbs_jobgroup.id = wmbs_job.jobgroup AND
              wmbs_jobgroup.subscription = (SELECT id FROM wmbs_subscription
                                            WHERE fileset = (SELECT id FROM wmbs_fileset
                                                             WHERE name = :fileset))
            WHERE wmbs_job.state IN (
              SELECT id FROM wmbs_job_state
              WHERE name IN ('new', 'created', 'executing')
            )
            """
 
   def execute(self,fileset, conn = None, transaction = False):
        bindVars = {}
                     
        global allowedFilesets
        try: 
          index= allowedFilesets.index(fileset.lower().capitalize())
          bindVars.update({'fileset':allowedFilesets[index]})
        except (IndexError,ValueError):
          return { "Error" : "wrong fileset name", "hint" : allowedFilesets }
        
        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)

        return self.format(result)
