#!/usr/bin/env python
"""
_JobLifetimes_

T0Mon query: base class to produce job statistical plots 
"""

from WMCore.Database.DBFormatter import DBFormatter

class JobLifetime(DBFormatter):
    """
    retrieve stats of job life times

    """
##     subscription = None
    fileset = "YouNeedToOverrideThis"
    datatier = None

    def execute(self, stime, etime, run, conn = None, transaction = False):
        """
        create correct sql query and execute it

        """
        try:
            run = int(run)
        except ValueError:
            run = 0

        try:
            stime = int(stime)
        except ValueError:
            stime = 0

        try:
            etime = int(etime)
        except ValueError:
            etime = 0

        bindVars = { 'FILESET' : self.fileset }

        if stime > 0 and etime > 0:
            sqlTimeCheck = "WHERE jg.last_update > :STIME AND j.state_time < :ETIME"
            bindVars.update( { 'STIME' : stime,
                               'ETIME' : etime } )
        else: 
            sqlTimeCheck = "WHERE j.id > 0"

        if run > 0 or self.datatier != None:
            sqlAssocJoin = """INNER JOIN wmbs_job_assoc assoc ON
                                   assoc.job = j.id
                                 """
        else:
            sqlAssocJoin = ""

        if run > 0:
            sqlRunCheck = """INNER JOIN wmbs_file_runlumi_map ON
                               wmbs_file_runlumi_map.fileid = assoc.fileid AND
                               wmbs_file_runlumi_map.run = :RUN
                             """
            bindVars.update( { 'RUN' : run } )
        else:
            sqlRunCheck = ""

        if self.datatier != None:
            sqlDatatierCheck = """INNER JOIN wmbs_file_dataset_path_assoc ON
                                    wmbs_file_dataset_path_assoc.file_id = assoc.fileid
                                  INNER JOIN dataset_path ON
                                    dataset_path.id = wmbs_file_dataset_path_assoc.dataset_path_id
                                  INNER JOIN data_tier ON
                                    data_tier.id = dataset_path.data_tier AND
                                    data_tier.name = :DATATIER
                                  """
            bindVars.update( { 'DATATIER' : self.datatier } )
        else:
            sqlDatatierCheck = ""

        self.sql= """SELECT DISTINCT j.id as job_id,
                            j.state_time as endTime,
                            jg.last_update as startTime,
                            (j.state_time - jg.last_update) as diff
                     FROM wmbs_job j
                     INNER JOIN wmbs_job_state js ON
                       js.id = j.state
                     INNER JOIN wmbs_jobgroup jg ON
                       jg.id = j.jobgroup AND
                       jg.subscription = (SELECT id FROM wmbs_subscription
                                          WHERE fileset = (SELECT id FROM wmbs_fileset
                                                           WHERE name = :FILESET))
                     %s
                     %s
                     %s
                     %s
                     ORDER BY j.state_time
                     """ % (sqlAssocJoin,
                            sqlRunCheck,
                            sqlDatatierCheck,
                            sqlTimeCheck)

        # at least one of the 2 options (time/run) has to be activate:
        if not bindVars.has_key('STIME') and not bindVars.has_key('RUN'):
            return { "Error" : "missing parameter(s)" }

        result = self.dbi.processData(self.sql, bindVars, conn = conn,
                                      transaction = transaction)

        return self.formatDict(result)
