
from WMCore.HTTPFrontEnd.WorkQueue.Services.ServiceInterface import ServiceInterface
from WMCore.DAOFactory import DAOFactory

class Tier0RECOService(ServiceInterface):
    """
    _Tier0RECOService_
    
    Provice the tier0 REST services for RECO group 
    """
    
    def register(self):
        
        daoFactory = DAOFactory(package = "T0.DAS.Database",
                                     logger = self.model,
                                     dbinterface = self.model.dbi)
        
        # used by dropbox
        self.model.addDAO('GET', 'runs',
                          'Runs.Run',
                          daoFactory=daoFactory)

        # used by dropbox
        self.model.addDAO('GET',
                          'firstconditionsaferun',
                          'Runs.FirstConditionSafeRun',
                          daoFactory=daoFactory)

        # not used
        self.model.addDAO('GET', 'runsbystatus', 
                          'Runs.RunsByStates', args=['run_status'], 
                          daoFactory=daoFactory)

        # not used
        self.model.addDAO('GET', 'runsbyrecostatus', 
                          'Runs.RunsByRecoStartStatus', args=['reco_status'], 
                          daoFactory=daoFactory)

        # intended to be used by lumi group
        self.model.addDAO('GET', 'isexpresscomplete', 
                          'Runs.IsRunExpressComplete', args=['run'],
                          daoFactory=daoFactory)

        #
        # timing related daos
        #

        # used by Tier0Monitor
        # arguments : run
        self.model.addDAO('GET', 'recostatusbyrun', 
                          'Timing.RecoStartStatusByRun', args=['run'],
                          validation = [self.convertToRunList],
                          daoFactory=daoFactory)

        # used by Tier0Monitor
        self.model.addDAO('GET', 'recotimeleft', 'Timing.RecoStartTimeLeft', 
                          daoFactory=daoFactory)

        # used by Tier0Monitor
        # arguments : run
        self.model.addDAO('GET', 'recotimeleftbyrun', 
                          'Timing.RecoStartTimeLeftByRun', args=['run'],
                          validation = [self.convertToRunList],
                          daoFactory=daoFactory)
        
        # not used
        self.model.addDAO('GET', 'injectiontimebydataset', 
                          'Blocks.BlockInfoByDatasetPath', 
                          args=['datasetpath'],
                          daoFactory=daoFactory)
        
        
    def convertToRunList(self, input):
        """
        Normally it doesn't need to convert run string to int.
        DB handles it correctly.
        """
        if input.has_key('run'):
            runs = input['run']
            try:
                iter(runs)
                if type(runs) in types.StringTypes:
                    raise TypeError
            except TypeError:
                input['run'] = [runs]
        return input
